@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Angla (Usono)",
+"sq": "Albana",
 "am": "Amhara",
 "ar": "Araba",
 "ast": "Astura",
-"bg": "Bulgara",
 "bn": "Bengala",
 "bn-IN": "Bengala (Barato)",
-"bo": "Tibeta",
 "bs": "Bosna",
+"bg": "Bulgara",
 "ca": "Kataluna",
-"ca-valencia": "Kataluna (Valencilando)",
+"ca-valencia": "Catalan (Valencia)",
+"zh-CN": "Ĉina (simpligita)",
+"zh-TW": "Ĉina (tradicia)",
+"hr": "Kroata",
 "cs": "Ĉeĥa",
 "da": "Dana",
-"de": "Germana",
+"nl": "Nederlanda",
 "dz": "Butana",
-"el": "Greka",
 "en-GB": "Angla (UR)",
 "en-ZA": "Angla (SA)",
 "eo": "Esperanto",
-"es": "Hispana",
 "et": "Estona",
 "eu": "Eŭska",
 "fi": "Finna",
 "fr": "Franca",
 "gl": "Galega",
+"ka": "Kartvela",
+"de": "Germana",
+"el": "Greka",
 "gu": "Guĝarata",
 "he": "Hebrea",
 "hi": "Hindia",
-"hr": "Kroata",
 "hu": "Hungara",
 "id": "Indonezia",
 "is": "Islanda",
 "it": "Itala",
 "ja": "Japana",
-"ka": "Kartvela",
 "km": "Kamboĝa",
 "ko": "Korea",
 "lo": "Laosa",
-"lt": "Lithuanian",
-"lv": "Latvian",
+"lv": "Latva",
+"lt": "Litova",
 "mk": "Makedona",
-"nb": "Norwegian Bokmål",
-"ne": "Nepali",
-"nl": "Dutch",
-"nn": "Norwegian Nynorsk",
+"ne": "Nepalia",
+"nn": "Norvega (nynorsk)",
+"nb": "Norvega (bokmål)",
 "om": "Oroma",
-"pl": "Polish",
+"pl": "Pola",
 "pt": "Portugala",
-"pt-BR": "Portugala (Brazilo)",
+"pt-BR": "Portuguese (Brazil)",
 "ro": "Rumana",
-"ru": "Russian",
-"si": "Sinhala",
+"ru": "Rusa",
 "sid": "Sidama",
-"sk": "Slovak",
-"sl": "Slovenian",
-"sq": "Albanian",
-"sv": "Swedish",
-"ta": "Tamil",
-"tg": "Tajik",
-"tr": "Turkish",
-"ug": "Uyghur",
-"uk": "Ukrainian",
+"si": "Sinhala",
+"sk": "Slovaka",
+"sl": "Slovena",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Hispana",
+"sv": "Sveda",
+"tg": "Taĝika",
+"ta": "Tamila",
+"bo": "Tibeta",
+"tr": "Turka",
+"ug": "Ujgura",
+"uk": "Ukraina",
 "vi": "Vjetnama",
-"zh-CN": "Chinese (Simplified)",
-"zh-TW": "Chinese (Traditional)",
 };
